==> relative_time-2.0.1.tar.gz: lib/src/relative_time_extension.dart <==
import 'package:flutter/widgets.dart';
import 'package:relative_time/src/l10n/relative_time_localizations.dart';
import 'package:relative_time/src/relative_time.dart';
import 'package:relative_time/src/time_unit.dart';

/// Extends [DateTime] to include formatting as relative time.
extension RelativeTimeExtension on DateTime {
  /// Formats this [DateTime] as the relative time compared to now.
  ///
  /// [context] must contain a retrievable [RelativeTimeLocalizations].
  ///
  /// Set [timeUnits] to customize the [TimeUnit]s that may be used. Defaults to
  /// [defaultTimeUnits].
  ///
  /// [numeric] determines whether or not numeric values should be preferred
  /// over natural language. Defaults to false.
  String relativeTime(
    BuildContext context, {
    Iterable<TimeUnit> timeUnits = defaultTimeUnits,
    bool numeric = false,
  }) =>
      RelativeTime(
        context,
        timeUnits: timeUnits,
        numeric: numeric,
      ).format(this);

  /// Formats this [DateTime] as the relative time compared to now.
  ///
  /// [locale] will lookup the closest available localization.
  ///
  /// Set [timeUnits] to customize the [TimeUnit]s that may be used. Defaults to
  /// [defaultTimeUnits].
  ///
  /// [numeric] determines whether or not numeric values should be preferred
  /// over natural language. Defaults to false.
  String relativeTimeLocale(
    Locale locale, {
    Iterable<TimeUnit> timeUnits = defaultTimeUnits,
    bool numeric = false,
  }) =>
      RelativeTime.locale(
        locale,
        timeUnits: timeUnits,
        numeric: numeric,
      ).format(this);
}

==> relative_time-3.0.0.tar.gz: lib/src/relative_time_extension.dart <==
import 'package:flutter/widgets.dart';
import 'package:relative_time/src/l10n/relative_time_localizations.dart';
import 'package:relative_time/src/relative_time.dart';
import 'package:relative_time/src/time_unit.dart';

/// Extends [DateTime] to include formatting as relative time.
extension RelativeTimeExtension on DateTime {
  /// Formats this [DateTime] as the relative time compared to now.
  ///
  /// [context] must contain a retrievable [RelativeTimeLocalizations].
  ///
  /// Set [timeUnits] to customize the [TimeUnit]s that may be used. Defaults to
  /// all.
  ///
  /// [numeric] determines whether or not numeric values should be preferred
  /// over natural language. Defaults to false.
  String relativeTime(
    BuildContext context, {
    Iterable<TimeUnit> timeUnits = TimeUnit.values,
    bool numeric = false,
  }) =>
      RelativeTime(
        context,
        timeUnits: timeUnits,
        numeric: numeric,
      ).format(this);

  /// Formats this [DateTime] as the relative time compared to now.
  ///
  /// [locale] will lookup the closest available localization.
  ///
  /// Set [timeUnits] to customize the [TimeUnit]s that may be used. Defaults to
  /// all.
  ///
  /// [numeric] determines whether or not numeric values should be preferred
  /// over natural language. Defaults to false.
  String relativeTimeLocale(
    Locale locale, {
    Iterable<TimeUnit> timeUnits = TimeUnit.values,
    bool numeric = false,
  }) =>
      RelativeTime.locale(
        locale,
        timeUnits: timeUnits,
        numeric: numeric,
      ).format(this);
}
